#################
Expansion Modules
#################

FINE expansion modules provide additional functionalities to the user. These functionalities either run energy system models multiple times
or can be applied in the pre- and postprocessing of an energy system model run.

**Expansion Modules**

.. toctree::
   :maxdepth: 1

   
   optimizeTSAmultiStageDoc
   robustPipelineSizingDoc
   transformationPathDoc